"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
const fs_1 = __importDefault(require("fs"));
const axios_1 = __importDefault(require("axios"));
const url_1 = require("url");
const stream = __importStar(require("stream"));
const EventTable_1 = __importDefault(require("./EventTable"));
const Job_1 = __importDefault(require("./Job"));
const ScanStatus_1 = __importDefault(require("./ScanStatus"));
const WalkupScanDestination_1 = __importDefault(require("./WalkupScanDestination"));
const WalkupScanToCompDestination_1 = __importDefault(require("./WalkupScanToCompDestination"));
const WalkupScanDestinations_1 = __importDefault(require("./WalkupScanDestinations"));
const WalkupScanToCompDestinations_1 = __importDefault(require("./WalkupScanToCompDestinations"));
const WalkupScanToCompEvent_1 = __importDefault(require("./WalkupScanToCompEvent"));
const DiscoveryTree_1 = __importDefault(require("./DiscoveryTree"));
const WalkupScanToCompManifest_1 = __importDefault(require("./WalkupScanToCompManifest"));
const WalkupScanToCompCaps_1 = __importDefault(require("./WalkupScanToCompCaps"));
const WalkupScanManifest_1 = __importDefault(require("./WalkupScanManifest"));
const ScanJobManifest_1 = __importDefault(require("./ScanJobManifest"));
const ScanCaps_1 = __importDefault(require("./ScanCaps"));
const delay_1 = require("./delay");
const net = __importStar(require("net"));
let printerIP = "192.168.1.11";
let debug = false;
let callCount = 0;
class HPApi {
    static setDeviceIP(ip) {
        printerIP = ip;
    }
    static setDebug(dbg) {
        debug = dbg;
    }
    static logDebug(callId, isRequest, msg) {
        if (debug) {
            const id = String(callId).padStart(4, "0");
            const content = typeof msg === "string" ? msg : JSON.stringify(msg);
            console.log(id + (isRequest ? " -> " : " <- ") + content);
        }
    }
    static async callAxios(request) {
        var _a, _b, _c, _d;
        callCount++;
        if (request.timeout === 0) {
            request.timeout = 100000;
        }
        HPApi.logDebug(callCount, true, request);
        try {
            const response = await (0, axios_1.default)(request);
            HPApi.logDebug(callCount, false, {
                status: response.status,
                data: response.data,
                headers: response.headers,
                statusText: response.statusText,
            });
            return response;
        }
        catch (error) {
            const axiosError = error;
            if (axiosError.isAxiosError) {
                HPApi.logDebug(callCount, false, {
                    status: (_a = axiosError.response) === null || _a === void 0 ? void 0 : _a.status,
                    data: (_b = axiosError.response) === null || _b === void 0 ? void 0 : _b.data,
                    headers: (_c = axiosError.response) === null || _c === void 0 ? void 0 : _c.headers,
                    statusText: (_d = axiosError.response) === null || _d === void 0 ? void 0 : _d.statusText,
                });
            }
            throw error;
        }
    }
    static async isAlive(timeout = null) {
        const definedTimeout = timeout || 10000; // default of 10 seconds
        return new Promise((resolve) => {
            const socket = net.createConnection(80, printerIP, () => {
                clearTimeout(timer);
                resolve(true);
                socket.end();
            });
            const timer = setTimeout(() => {
                resolve(false);
                socket.end();
            }, definedTimeout);
            socket.on("error", () => {
                clearTimeout(timer);
                resolve(false);
            });
        });
    }
    static async waitDeviceUp(deviceUpPollingInterval) {
        let first = true;
        while (!(await HPApi.isAlive())) {
            if (first) {
                console.log(`Device ip: ${printerIP} is down! [${new Date().toISOString()}]`);
            }
            first = false;
            await (0, delay_1.delay)(deviceUpPollingInterval);
        }
        if (!first) {
            console.log(`Device ip: ${printerIP} is up again! [${new Date().toISOString()}]`);
        }
    }
    static async getDiscoveryTree() {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: "/DevMgmt/DiscoveryTree.xml",
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return DiscoveryTree_1.default.createDiscoveryTree(response.data);
        }
    }
    static async getWalkupScanDestinations(uri = "/WalkupScan/WalkupScanDestinations") {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return WalkupScanDestinations_1.default.createWalkupScanDestinations(response.data);
        }
    }
    static async getWalkupScanToCompDestinations() {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: "/WalkupScanToComp/WalkupScanToCompDestinations",
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return WalkupScanToCompDestinations_1.default.createWalkupScanToCompDestinations(response.data);
        }
    }
    static async getWalkupScanManifest(uri) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return WalkupScanManifest_1.default.createWalkupScanManifest(response.data);
        }
    }
    static async getWalkupScanToCompManifest(uri) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return WalkupScanToCompManifest_1.default.createWalkupScanToCompManifest(response.data);
        }
    }
    static async getScanJobManifest(uri) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return ScanJobManifest_1.default.createScanJobManifest(response.data);
        }
    }
    static async getScanCaps(uri) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return ScanCaps_1.default.createScanCaps(response.data);
        }
    }
    static async getWalkupScanToCompCaps(uri) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: uri,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw new Error(response.statusText);
        }
        else {
            return WalkupScanToCompCaps_1.default.createWalkupScanToCompCaps(response.data);
        }
    }
    static async getWalkupScanToCompEvent(compEventURI) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: compEventURI,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw response;
        }
        else {
            return WalkupScanToCompEvent_1.default.createWalkupScanToCompEvent(response.data);
        }
    }
    static async removeDestination(walkupScanDestination) {
        let path;
        if (walkupScanDestination.resourceURI.startsWith("http")) {
            let urlInfo = new url_1.URL(walkupScanDestination.resourceURI);
            if (urlInfo.pathname === null) {
                throw new Error(`invalid walkupScanDestination.resourceURI: ${walkupScanDestination.resourceURI}`);
            }
            path = urlInfo.pathname;
        }
        else {
            path = walkupScanDestination.resourceURI;
        }
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: path,
            method: "DELETE",
            responseType: "text",
        });
        if (response.status === 204 || response.status == 200) {
            return true;
        }
        else {
            throw response;
        }
    }
    static async registerWalkupScanDestination(destination) {
        const xml = await destination.toXML();
        const url = "/WalkupScan/WalkupScanDestinations";
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: url,
            method: "POST",
            headers: { "Content-Type": "text/xml" },
            data: xml,
            responseType: "text",
        });
        if (response.status === 201 && response.headers.location != null) {
            return new url_1.URL(response.headers.location).pathname;
        }
        else {
            throw response;
        }
    }
    static async registerWalkupScanToCompDestination(destination) {
        const xml = await destination.toXML();
        const url = "/WalkupScanToComp/WalkupScanToCompDestinations";
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: url,
            method: "POST",
            headers: { "Content-Type": "text/xml" },
            data: xml,
            responseType: "text",
        });
        if (response.status === 201 && response.headers.location != null) {
            return new url_1.URL(response.headers.location).pathname;
        }
        else {
            throw response;
        }
    }
    static async getEvents(etag = "", decisecondTimeout = 0) {
        var _a;
        let url = this.appendTimeout("/EventMgmt/EventTable", decisecondTimeout);
        let headers = this.placeETagHeader(etag, {});
        let response;
        try {
            response = await HPApi.callAxios({
                baseURL: `http://${printerIP}`,
                url: url,
                method: "GET",
                responseType: "text",
                headers: headers,
                timeout: decisecondTimeout * 100 * 1.1,
            });
        }
        catch (error) {
            const axiosError = error;
            if (!axiosError.isAxiosError)
                throw error;
            if (((_a = axiosError.response) === null || _a === void 0 ? void 0 : _a.status) === 304) {
                return {
                    etag: etag,
                    eventTable: new EventTable_1.default({}),
                };
            }
            throw error;
        }
        const etagReceived = response.headers["etag"];
        if (etagReceived == null) {
            throw response;
        }
        const content = response.data;
        return EventTable_1.default.createEtagEventTable(content, etagReceived);
    }
    static placeETagHeader(etag, headers) {
        if (etag !== "") {
            headers["If-None-Match"] = etag;
        }
        return headers;
    }
    static appendTimeout(url, timeout = null) {
        if (timeout == null) {
            timeout = 1200;
        }
        if (timeout > 0) {
            url += "?timeout=" + timeout;
        }
        return url;
    }
    static async getDestination(destinationURL) {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: destinationURL,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw response;
        }
        else {
            const content = response.data;
            if (destinationURL.includes("WalkupScanToComp")) {
                return WalkupScanToCompDestination_1.default.createWalkupScanToCompDestination(content);
            }
            else {
                return WalkupScanDestination_1.default.createWalkupScanDestination(content);
            }
        }
    }
    static async getScanStatus() {
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}`,
            url: "/Scan/Status",
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw response;
        }
        else {
            let content = response.data;
            return ScanStatus_1.default.createScanStatus(content);
        }
    }
    static delay(t) {
        return new Promise(function (resolve) {
            setTimeout(resolve, t);
        });
    }
    static async postJob(job) {
        await HPApi.delay(500);
        const xml = await job.toXML();
        const response = await HPApi.callAxios({
            baseURL: `http://${printerIP}:8080`,
            url: "/Scan/Jobs",
            method: "POST",
            headers: { "Content-Type": "text/xml" },
            data: xml,
            responseType: "text",
        });
        if (response.status === 201 && response.headers.location != null) {
            return response.headers.location;
        }
        else {
            throw response;
        }
    }
    /**
     * @param jobURL
     * @return {Promise<Job|*>}
     */
    static async getJob(jobURL) {
        const response = await HPApi.callAxios({
            url: jobURL,
            method: "GET",
            responseType: "text",
        });
        if (response.status !== 200) {
            throw response;
        }
        else {
            const content = response.data;
            return Job_1.default.createJob(content);
        }
    }
    static async downloadPage(binaryURL, destination) {
        const { data } = await axios_1.default.request({
            baseURL: `http://${printerIP}:8080`,
            url: binaryURL,
            method: "GET",
            responseType: "stream",
        });
        const destinationFileStream = fs_1.default.createWriteStream(destination);
        data.pipe(destinationFileStream);
        await (0, util_1.promisify)(stream.finished)(destinationFileStream);
        return destination;
    }
}
exports.default = HPApi;
//# sourceMappingURL=HPApi.js.map