"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const xml2js_1 = require("xml2js");
const parser = new xml2js_1.Parser();
const util_1 = require("util");
const parseString = (0, util_1.promisify)(parser.parseString);
class Job {
    constructor(data) {
        this.data = data;
    }
    static async createJob(content) {
        const parsed = await parseString(content);
        return new Job(parsed);
    }
    get currentPageNumber() {
        let preScanPage = this.data["j:Job"].ScanJob[0].PreScanPage;
        if (preScanPage) {
            return preScanPage[0].PageNumber[0];
        }
        else {
            return null;
        }
    }
    get totalPageNumber() {
        if (this.data["j:Job"].ScanJob[0].PostScanPage) {
            return parseInt(this.data["j:Job"].ScanJob[0].PostScanPage[0].PageNumber[0], 10);
        }
        return null;
    }
    get jobState() {
        return this.data["j:Job"]["j:JobState"][0];
    }
    get pageState() {
        let preScanPage = this.data["j:Job"].ScanJob[0].PreScanPage;
        if (preScanPage) {
            return preScanPage[0].PageState[0];
        }
        else {
            return null;
        }
    }
    get binaryURL() {
        if (this.data["j:Job"].ScanJob[0].PreScanPage) {
            return this.data["j:Job"].ScanJob[0].PreScanPage[0].BinaryURL[0];
        }
        return null;
    }
    get imageWidth() {
        var _a, _b, _c, _d, _e;
        if (!Object.prototype.hasOwnProperty.call(this.data["j:Job"].ScanJob[0], "PreScanPage")) {
            return null;
        }
        return parseInt((_e = (_d = (_c = (_b = (_a = this.data["j:Job"].ScanJob[0].PreScanPage) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.BufferInfo) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.ImageWidth[0]) !== null && _e !== void 0 ? _e : "");
    }
    get imageHeight() {
        if (this.data["j:Job"].ScanJob[0].PreScanPage) {
            return parseInt(this.data["j:Job"].ScanJob[0].PreScanPage[0].BufferInfo[0]
                .ImageHeight[0]);
        }
        return null;
    }
    get xResolution() {
        var _a, _b, _c, _d, _e, _f, _g;
        if (this.data["j:Job"].ScanJob[0].PreScanPage) {
            return parseInt((_g = (_f = (_e = (_d = (_c = (_b = (_a = this.data["j:Job"].ScanJob[0].PreScanPage) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.BufferInfo) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.ScanSettings) === null || _e === void 0 ? void 0 : _e[0]) === null || _f === void 0 ? void 0 : _f.XResolution[0]) !== null && _g !== void 0 ? _g : "");
        }
        return null;
    }
    get yResolution() {
        var _a, _b, _c, _d, _e, _f, _g;
        if (Object.prototype.hasOwnProperty.call(this.data["j:Job"].ScanJob[0], "PreScanPage")) {
            return parseInt((_g = (_f = (_e = (_d = (_c = (_b = (_a = this.data["j:Job"].ScanJob[0].PreScanPage) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.BufferInfo) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.ScanSettings) === null || _e === void 0 ? void 0 : _e[0]) === null || _f === void 0 ? void 0 : _f.YResolution[0]) !== null && _g !== void 0 ? _g : "");
        }
        return null;
    }
}
exports.default = Job;
//# sourceMappingURL=Job.js.map