"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const dateformat_1 = __importDefault(require("dateformat"));
const os_1 = __importDefault(require("os"));
const fs_1 = require("fs");
const fs_2 = __importDefault(require("fs"));
class PathHelper {
    static getFileForPage(folder, scanCount, currentPageNumber, filePattern, extension, date) {
        if (filePattern) {
            return path_1.default.join(folder, `${(0, dateformat_1.default)(date, filePattern)}.${extension}`);
        }
        return this.makeUnique(path_1.default.join(folder, `scan${scanCount}_page${currentPageNumber}.${extension}`), date);
    }
    static async getNextScanNumber(folder, currentScanCount, filePattern) {
        if (filePattern) {
            return currentScanCount++;
        }
        const files = await fs_1.promises.readdir(folder);
        for (let i = currentScanCount + 1; i < Number.MAX_SAFE_INTEGER; i++) {
            const currentScanCountProbe = `scan${i}`;
            if (!(files.some((x) => x.startsWith(currentScanCountProbe)) &&
                files.some((x) => x.startsWith(currentScanCountProbe + "_") ||
                    files.some((x) => x.startsWith(currentScanCountProbe + "."))))) {
                return i;
            }
        }
        return Promise.reject(`Unable to find the valid scan number in folder ${folder}`);
    }
    static makeUnique(filePath, date) {
        if (!fs_2.default.existsSync(filePath)) {
            return filePath;
        }
        let parsed = path_1.default.parse(filePath);
        let tryName = `${parsed.dir}${path_1.default.sep}${parsed.name}_${(0, dateformat_1.default)(date, "yyyymmdd")}${parsed.ext}`;
        if (!fs_2.default.existsSync(tryName)) {
            return tryName;
        }
        parsed = path_1.default.parse(tryName);
        let i = "a";
        while (i <= "z") {
            tryName = `${parsed.dir}${path_1.default.sep}${parsed.name}_${i}${parsed.ext}`;
            if (!fs_2.default.existsSync(tryName)) {
                return tryName;
            }
            i = String.fromCharCode(i.charCodeAt(0) + 1);
        }
        throw new Error(`Can not create unique file: ${filePath} iterated until: ${tryName}`);
    }
    static getFileForScan(folder, scanCount, filePattern, extension, date) {
        if (filePattern) {
            return path_1.default.join(folder, `${(0, dateformat_1.default)(date, filePattern)}.${extension}`);
        }
        return path_1.default.join(folder, `scan${scanCount}.${extension}`);
    }
    static async getOutputFolder(folder) {
        if (typeof folder !== "string") {
            return fs_1.promises.mkdtemp(path_1.default.join(os_1.default.tmpdir(), "scan-to-pc"));
        }
        return folder;
    }
}
exports.default = PathHelper;
//# sourceMappingURL=PathHelper.js.map