"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const xml2js_1 = require("xml2js");
const parser = new xml2js_1.Parser();
const util_1 = require("util");
const InputSource_1 = require("./InputSource");
const parseString = (0, util_1.promisify)(parser.parseString);
class ScanStatus {
    constructor(data) {
        this.data = data;
    }
    static async createScanStatus(content) {
        const parsed = await parseString(content);
        return new ScanStatus(parsed);
    }
    get scannerState() {
        return this.data["ScanStatus"].ScannerState["0"];
    }
    get adfState() {
        if (Object.prototype.hasOwnProperty.call(this.data["ScanStatus"], "AdfState")) {
            //not all printers have an automatic document feeder
            return this.data["ScanStatus"].AdfState["0"];
        }
        else {
            return "";
        }
    }
    isLoaded() {
        return this.adfState === "Loaded";
    }
    getInputSource() {
        return this.isLoaded() ? InputSource_1.InputSource.Adf : InputSource_1.InputSource.Platen;
    }
}
exports.default = ScanStatus;
//# sourceMappingURL=ScanStatus.js.map