"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const xml2js_1 = require("xml2js");
const util_1 = require("util");
const parser = new xml2js_1.Parser();
const parseString = (0, util_1.promisify)(parser.parseString);
class WalkupScanDestination {
    constructor(data) {
        this.data = data;
    }
    static async createWalkupScanDestination(content) {
        const parsed = await parseString(content);
        return new WalkupScanDestination(parsed["wus:WalkupScanDestinations"]["wus:WalkupScanDestination"][0]);
    }
    get name() {
        return this.data["dd:Name"][0];
    }
    get hostname() {
        return this.data["dd3:Hostname"][0];
    }
    get resourceURI() {
        return this.data["dd:ResourceURI"][0];
    }
    get shortcut() {
        if (Object.prototype.hasOwnProperty.call(this.data, "wus:WalkupScanSettings")) {
            return this.data["wus:WalkupScanSettings"]["0"]["wus:Shortcut"][0];
        }
        return null;
    }
    get scanPlexMode() {
        if (Object.prototype.hasOwnProperty.call(this.data, "wus:WalkupScanSettings")) {
            return this.data["wus:WalkupScanSettings"]["0"]["scantype:ScanSettings"][0]["dd:ScanPlexMode"][0];
        }
        return null;
    }
}
exports.default = WalkupScanDestination;
//# sourceMappingURL=WalkupScanDestination.js.map