"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearRegistrations = exports.waitScanEvent = exports.waitForScanEvent = exports.waitScanRequest = void 0;
const HPApi_1 = __importDefault(require("./HPApi"));
const Destination_1 = __importDefault(require("./Destination"));
async function waitScanRequest(compEventURI) {
    const waitMax = 50;
    for (let i = 0; i < waitMax; i++) {
        let walkupScanToCompEvent = await HPApi_1.default.getWalkupScanToCompEvent(compEventURI);
        let message = walkupScanToCompEvent.eventType;
        if (message === "HostSelected") {
            // this ok to wait
        }
        else if (message === "ScanRequested") {
            break;
        }
        else if (message === "ScanNewPageRequested") {
            break;
        }
        else if (message === "ScanPagesComplete") {
            console.log("no more page to scan, scan is finished");
            return false;
        }
        else {
            console.log(`Unknown eventType: ${message}`);
            return false;
        }
        console.log(`Waiting user input: ${i + 1}/${waitMax}`);
        await new Promise((resolve) => setTimeout(resolve, 1000)); //wait 1s
    }
    return true;
}
exports.waitScanRequest = waitScanRequest;
async function waitForScanEvent(resourceURI, afterEtag = null) {
    console.log("Start listening for new ScanEvent");
    let eventTable = await HPApi_1.default.getEvents(afterEtag !== null && afterEtag !== void 0 ? afterEtag : "");
    let acceptedScanEvent = null;
    let currentEtag = eventTable.etag;
    while (acceptedScanEvent == null) {
        eventTable = await HPApi_1.default.getEvents(currentEtag, 1200);
        currentEtag = eventTable.etag;
        acceptedScanEvent = eventTable.eventTable.events.find((ev) => ev.isScanEvent &&
            ev.destinationURI &&
            ev.destinationURI.indexOf(resourceURI) >= 0);
    }
    return acceptedScanEvent;
}
exports.waitForScanEvent = waitForScanEvent;
async function registerWalkupScanToCompDestination(registrationConfig) {
    const walkupScanDestinations = await HPApi_1.default.getWalkupScanToCompDestinations();
    const destinations = walkupScanDestinations.destinations;
    console.log("Host destinations fetched:", destinations.map((d) => d.name).join(", "));
    const hostname = registrationConfig.label;
    const destination = destinations.find((x) => x.name === hostname);
    let resourceURI;
    if (destination) {
        console.log(`Re-using existing destination: ${hostname} - ${destination.resourceURI}`);
        resourceURI = destination.resourceURI;
    }
    else {
        resourceURI = await HPApi_1.default.registerWalkupScanToCompDestination(new Destination_1.default(hostname, hostname, true));
        console.log(`New Destination registered: ${hostname} - ${resourceURI}`);
    }
    console.log(`Using: ${hostname}`);
    return resourceURI;
}
async function registerWalkupScanDestination(registrationConfig) {
    const walkupScanDestinations = await HPApi_1.default.getWalkupScanDestinations();
    const destinations = walkupScanDestinations.destinations;
    console.log("Host destinations fetched:", destinations.map((d) => d.name).join(", "));
    const hostname = registrationConfig.label;
    const destination = destinations.find((x) => x.name === hostname);
    let resourceURI;
    if (destination) {
        console.log(`Re-using existing destination: ${hostname} - ${destination.resourceURI}`);
        resourceURI = destination.resourceURI;
    }
    else {
        resourceURI = await HPApi_1.default.registerWalkupScanDestination(new Destination_1.default(hostname, hostname, false));
        console.log(`New Destination registered: ${hostname} - ${resourceURI}`);
    }
    console.log(`Using: ${hostname}`);
    return resourceURI;
}
async function waitScanEvent(deviceCapabilities, registrationConfig) {
    let resourceURI;
    if (deviceCapabilities.useWalkupScanToComp) {
        resourceURI = await registerWalkupScanToCompDestination(registrationConfig);
    }
    else {
        resourceURI = await registerWalkupScanDestination(registrationConfig);
    }
    console.log("Waiting scan event for:", resourceURI);
    return await waitForScanEvent(resourceURI);
}
exports.waitScanEvent = waitScanEvent;
async function clearRegistrations() {
    const dests = await HPApi_1.default.getWalkupScanToCompDestinations();
    for (let i = 0; i < dests.destinations.length; i++) {
        console.log(`Removing: ${dests.destinations[i].name}`);
        await HPApi_1.default.removeDestination(dests.destinations[i]);
    }
}
exports.clearRegistrations = clearRegistrations;
//# sourceMappingURL=listening.js.map