"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readDeviceCapabilities = void 0;
const HPApi_1 = __importDefault(require("./HPApi"));
async function readDeviceCapabilities() {
    let supportsMultiItemScanFromPlaten = true;
    const discoveryTree = await HPApi_1.default.getDiscoveryTree();
    let walkupScanToCompCaps = null;
    if (discoveryTree.WalkupScanToCompManifestURI != null) {
        const walkupScanToCompManifest = await HPApi_1.default.getWalkupScanToCompManifest(discoveryTree.WalkupScanToCompManifestURI);
        if (walkupScanToCompManifest.WalkupScanToCompCapsURI != null) {
            walkupScanToCompCaps = await HPApi_1.default.getWalkupScanToCompCaps(walkupScanToCompManifest.WalkupScanToCompCapsURI);
            supportsMultiItemScanFromPlaten =
                walkupScanToCompCaps.supportsMultiItemScanFromPlaten;
        }
    }
    else if (discoveryTree.WalkupScanManifestURI != null) {
        const walkupScanManifest = await HPApi_1.default.getWalkupScanManifest(discoveryTree.WalkupScanManifestURI);
        if (walkupScanManifest.walkupScanDestinationsURI != null) {
            await HPApi_1.default.getWalkupScanDestinations(walkupScanManifest.walkupScanDestinationsURI);
        }
    }
    else {
        console.log("Unknown device!");
    }
    let scanCaps = null;
    if (discoveryTree.ScanJobManifestURI != null) {
        const scanJobManifest = await HPApi_1.default.getScanJobManifest(discoveryTree.ScanJobManifestURI);
        if (scanJobManifest.ScanCapsURI != null) {
            scanCaps = await HPApi_1.default.getScanCaps(scanJobManifest.ScanCapsURI);
        }
    }
    return {
        supportsMultiItemScanFromPlaten,
        useWalkupScanToComp: walkupScanToCompCaps != null,
        platenMaxWidth: (scanCaps === null || scanCaps === void 0 ? void 0 : scanCaps.platenMaxWidth) || null,
        platenMaxHeight: (scanCaps === null || scanCaps === void 0 ? void 0 : scanCaps.platenMaxHeight) || null,
        adfMaxWidth: (scanCaps === null || scanCaps === void 0 ? void 0 : scanCaps.adfMaxWidth) || null,
        adfMaxHeight: (scanCaps === null || scanCaps === void 0 ? void 0 : scanCaps.adfMaxHeight) || null,
    };
}
exports.readDeviceCapabilities = readDeviceCapabilities;
//# sourceMappingURL=readDeviceCapabilities.js.map