"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mocha_1 = require("mocha");
const chai_1 = require("chai");
const JpegUtil_1 = __importDefault(require("../src/JpegUtil"));
const fs_1 = __importDefault(require("fs"));
const promises_1 = __importDefault(require("fs/promises"));
const path_1 = __importDefault(require("path"));
const fs = { ...(fs_1.default), ...(promises_1.default) };
(0, mocha_1.describe)("JpegUtil", () => {
    (0, mocha_1.describe)("Work on sample.jpg", () => {
        it("Reading JPEG size is possible", async () => {
            const buffer = await fs.readFile(path_1.default.resolve(__dirname, "./asset/sample.jpg"));
            const size = JpegUtil_1.default.GetJpgSize(buffer);
            (0, chai_1.expect)(size === null || size === void 0 ? void 0 : size.height).to.be.eq(300);
            (0, chai_1.expect)(size === null || size === void 0 ? void 0 : size.width).to.be.eq(400);
        });
        it("Writing JPEG size is possible", async () => {
            const buffer = await fs.readFile(path_1.default.resolve(__dirname, "./asset/sample.jpg"));
            const sizeWritten = JpegUtil_1.default.setJpgSize(buffer, {
                height: 1200,
                width: 800,
            });
            (0, chai_1.expect)(sizeWritten).to.be.true;
            const size = JpegUtil_1.default.GetJpgSize(buffer);
            (0, chai_1.expect)(size === null || size === void 0 ? void 0 : size.height).to.be.eq(1200);
            (0, chai_1.expect)(size === null || size === void 0 ? void 0 : size.width).to.be.eq(800);
        });
    });
    (0, mocha_1.describe)("Jpeg size", () => {
        it("allows to set height", async () => {
            const buffer = await fs.readFile(path_1.default.resolve(__dirname, "./asset/adf_bytes_scan.jpg"));
            const sizeWritten = JpegUtil_1.default.setJpgSize(buffer, {
                height: 2322,
                width: 1654,
            });
            (0, chai_1.expect)(sizeWritten).to.be.true;
            fs.writeFileSync(path_1.default.resolve(__dirname, "./asset/adf_bytes_scan_height_fixed.jpg"), buffer);
        });
    });
    (0, mocha_1.describe)("Fix a corrupted adf scan", () => {
        it("Fix image size based on DNL marker content", async () => {
            const buffer = await fs.readFile(path_1.default.resolve(__dirname, "./asset/adf_bytes_scan.jpg"));
            const sizeFixed = JpegUtil_1.default.fixSizeWithDNL(buffer);
            (0, chai_1.expect)(sizeFixed).to.be.eq(2322);
            fs.writeFileSync(path_1.default.resolve(__dirname, "./asset/adf_bytes_scan_height_fixed.jpg"), buffer);
        });
    });
});
//# sourceMappingURL=JpegUtil.test.js.map