"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mocha_1 = require("mocha");
const chai_1 = require("chai");
const chai_2 = __importDefault(require("chai"));
const chai_string_1 = __importDefault(require("chai-string"));
const PathHelper_1 = __importDefault(require("../src/PathHelper"));
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
chai_2.default.use(chai_string_1.default);
const now = new Date();
(0, mocha_1.describe)("PathHelper", () => {
    (0, mocha_1.describe)("getFileForPage", () => {
        it("Can format a file with formatted timestamp", async () => {
            const nextFileName = PathHelper_1.default.getFileForPage("someFolder", 2, 1, '"scan"_dd.mm.yyyy_HH:MM:ss', "jpg", now);
            (0, chai_1.expect)(nextFileName).to.be.eq(`someFolder${path_1.default.sep}scan_${("" + now.getDate()).padStart(2, "0")}.${("" +
                (now.getMonth() + 1)).padStart(2, "0")}.${("" + now.getFullYear()).padStart(4, "0")}_${("" + now.getHours()).padStart(2, "0")}:${("" + now.getMinutes()).padStart(2, "0")}:${("" + now.getSeconds()).padStart(2, "0")}.jpg`);
        });
        it("Can format a file based on scan count and page number", async () => {
            const nextFileName = PathHelper_1.default.getFileForPage("someFolder", 2, 1, undefined, "jpg", now);
            (0, chai_1.expect)(nextFileName).to.be.eq(`someFolder${path_1.default.sep}scan2_page1.jpg`);
        });
    });
    (0, mocha_1.describe)("getFileForScan", () => {
        it("Can format a file with formatted timestamp", async () => {
            const nextFileName = PathHelper_1.default.getFileForScan("someFolder", 2, '"scan"_dd.mm.yyyy_HH:MM:ss', "pdf", now);
            (0, chai_1.expect)(nextFileName).to.be.eq(`someFolder${path_1.default.sep}scan_${("" + now.getDate()).padStart(2, "0")}.${("" +
                (now.getMonth() + 1)).padStart(2, "0")}.${("" + now.getFullYear()).padStart(4, "0")}_${("" + now.getHours()).padStart(2, "0")}:${("" + now.getMinutes()).padStart(2, "0")}:${("" + now.getSeconds()).padStart(2, "0")}.pdf`);
        });
        it("Can format a file based on scan count and page number", async () => {
            const nextFileName = PathHelper_1.default.getFileForScan("someFolder", 2, undefined, "pdf", now);
            (0, chai_1.expect)(nextFileName).to.be.eq(`someFolder${path_1.default.sep}scan2.pdf`);
        });
    });
    (0, mocha_1.describe)("getOutputFolder", () => {
        (0, mocha_1.describe)("A folder given", () => {
            it("it is returned", async () => {
                const folder = await PathHelper_1.default.getOutputFolder("someFolder");
                (0, chai_1.expect)(folder).to.be.eq("someFolder");
            });
        });
        (0, mocha_1.describe)("No folder given", () => {
            it("it return a temp folder", async () => {
                const folder = await PathHelper_1.default.getOutputFolder();
                (0, chai_1.expect)(folder).to.startWith(os_1.default.tmpdir());
            });
            it("it return a folder that exist", async () => {
                const folder = await PathHelper_1.default.getOutputFolder();
                (0, chai_1.expect)(fs_1.default.existsSync(folder)).to.be.true;
            });
            it("it return a different folder for every call", async () => {
                const folder = await PathHelper_1.default.getOutputFolder();
                (0, chai_1.expect)(folder).to.be.not.eq(await PathHelper_1.default.getOutputFolder());
            });
        });
    });
    (0, mocha_1.describe)("makeUnique", () => {
        it("return the file if it does not exist first", async () => {
            const folder = await PathHelper_1.default.getOutputFolder();
            const filePath = path_1.default.join(folder, "someFolder.pdf");
            const uniqueFile = PathHelper_1.default.makeUnique(filePath, now);
            (0, chai_1.expect)(filePath).to.be.eq(uniqueFile);
        });
        it("return another file in case of conflict", async () => {
            const folder = await PathHelper_1.default.getOutputFolder();
            const filePath = path_1.default.join(folder, "someFolder.pdf");
            fs_1.default.openSync(filePath, "w");
            const uniqueFile = PathHelper_1.default.makeUnique(filePath, now);
            (0, chai_1.expect)(filePath).to.be.not.eq(uniqueFile);
        });
        it("return another two conflict", async () => {
            const folder = await PathHelper_1.default.getOutputFolder();
            let filePath = path_1.default.join(folder, "someFolder.pdf");
            fs_1.default.openSync(filePath, "w");
            const another = PathHelper_1.default.makeUnique(filePath, now);
            fs_1.default.openSync(another, "w");
            const uniqueFile = PathHelper_1.default.makeUnique(filePath, now);
            (0, chai_1.expect)(filePath).to.be.not.eq(uniqueFile);
            (0, chai_1.expect)(another).to.be.not.eq(uniqueFile);
        });
        it("conflict resolution terminate with error", async () => {
            const folder = await PathHelper_1.default.getOutputFolder();
            let filePath = path_1.default.join(folder, "someFolder.pdf");
            fs_1.default.openSync(filePath, "w");
            (0, chai_1.expect)(() => {
                for (let i = 0; i < 50; ++i) {
                    const another = PathHelper_1.default.makeUnique(filePath, now);
                    fs_1.default.openSync(another, "w");
                }
            }).to.throw(/Can not create unique file:/);
        });
    });
});
//# sourceMappingURL=PathHelper.test.js.map