"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mocha_1 = require("mocha");
const chai_1 = require("chai");
const scanProcessing_1 = require("../src/scanProcessing");
const InputSource_1 = require("../src/InputSource");
(0, mocha_1.describe)("scanProcessing", () => {
    let scanConfig;
    let deviceCapabilities;
    beforeEach(async () => {
        scanConfig = {
            resolution: 200,
            width: null,
            height: null,
            directoryConfig: {
                directory: undefined,
                tempDirectory: undefined,
                filePattern: undefined,
            },
        };
        deviceCapabilities = {
            supportsMultiItemScanFromPlaten: false,
            useWalkupScanToComp: false,
            platenMaxWidth: null,
            platenMaxHeight: null,
            adfMaxWidth: null,
            adfMaxHeight: null,
        };
    });
    (0, mocha_1.describe)("getScanWidth", async () => {
        const inputSource = InputSource_1.InputSource.Adf;
        (0, mocha_1.describe)("Adf", async () => {
            it("Does not define a value if nothing provided", async () => {
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(null);
            });
            it("Does not define a value if negative provided", async () => {
                scanConfig.width = -1;
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(null);
            });
            it("Define the value if no max available from device", async () => {
                scanConfig.width = 2583;
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(2583);
            });
        });
        (0, mocha_1.describe)("Platen", async () => {
            const inputSource = InputSource_1.InputSource.Platen;
            it("Does not define a value if nothing provided", async () => {
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(null);
            });
            it("Does not define a value if negative provided", async () => {
                scanConfig.width = -1;
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(null);
            });
            it("Define the value if no max available from device", async () => {
                scanConfig.width = 2583;
                const width = (0, scanProcessing_1.getScanWidth)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(2583);
            });
        });
    });
    (0, mocha_1.describe)("getScanHeight", async () => {
        const inputSource = InputSource_1.InputSource.Adf;
        (0, mocha_1.describe)("Adf", async () => {
            it("Does not define a value if nothing provided", async () => {
                const height = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(height).to.be.eq(null);
            });
            it("Does not define a value if negative provided", async () => {
                scanConfig.height = -1;
                const height = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(height).to.be.eq(null);
            });
            it("Define the value if no max available from device", async () => {
                scanConfig.height = 1269;
                const width = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(width).to.be.eq(1269);
            });
        });
        (0, mocha_1.describe)("Platen", async () => {
            const inputSource = InputSource_1.InputSource.Platen;
            it("Does not define a value if nothing provided", async () => {
                const height = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(height).to.be.eq(null);
            });
            it("Does not define a value if negative provided", async () => {
                scanConfig.height = -1;
                const height = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(height).to.be.eq(null);
            });
            it("Define the value if no max available from device", async () => {
                scanConfig.height = 1269;
                const height = (0, scanProcessing_1.getScanHeight)(scanConfig, inputSource, deviceCapabilities);
                (0, chai_1.expect)(height).to.be.eq(1269);
            });
        });
    });
});
//# sourceMappingURL=scanProcessing.test.js.map